---
feature_story: FS_84_11_73_28
feature_title: supported python versions
feature_status: TEST
---

Normally, `argrelay` supports two Python versions:
*   earliest supported one
*   latest one

See current status:
https://devguide.python.org/versions/

It does not mean `argrelay` cannot run with other versions - it simply means:
*   no tests run for other versions
*   no changes accepted to support versions earlier than the "earliest supported" one

To roll Python versions, use this `feature_story` tag to find (or mark) all places for update.
